@@ -80,17 +80,25 @@ class Switchport(NCSObject):
         self.name = Leaf(str)
         self.admin_state = Leaf(str)
         self.description = Leaf(str)
+        self.speed_and_duplex = Leaf(str)
+        
         self.mode = Container()
-
         self.mode.mode_choice = Choice(['access','trunk','default'])
+
         self.mode.mode_choice.access = Container()
         self.mode.mode_choice.access.vlan = Leaf(str)
-        self.mode.mode_choice.access.voip_enabled = Leaf(bool, value=False)
+        self.mode.mode_choice.access.voip_vlan = Leaf(str)
+        self.mode.mode_choice.access.poe = Container(hide_if_empty=True)
+        self.mode.mode_choice.access.poe.admin_state = Leaf(str)
+        self.mode.mode_choice.access.poe.maximum_power = Leaf(str)
+        self.mode.mode_choice.access.poe.priority = Leaf(str)
+
         self.mode.mode_choice.trunk = Container()
         self.mode.mode_choice.trunk.native_vlan = Leaf(str)
         self.mode.mode_choice.trunk.vlan_list = LeafList(str)
         self.mode.mode_choice.default = Container()
 
+
 class IPv6Subnet(NCSObject):
 
     def initialize_model(self):
@@ -133,7 +141,7 @@ class Networks(NCSObject):
     def initialize_model(self):
 
         self.network = List(Network)
-        self.network.set_ns("http://example.com/umnet-network")
+        self.network.set_ns("http://umnet.umich.edu/umnet-network")
 
 class NGFWVsyses(NCSObject):
     _path = "/config/services"
